@@ -4,11 +4,11 @@
 #'
 #' @param data A data frame.
 #' @param x,y Names of two variables present in the data.
-#' @param ci Confidence/Credible Interval level. If "default", then 0.95 for Frequentist and 0.89 for Bayesian (see documentation in the \pkg{bayestestR} package).
+#' @param ci Confidence/Credible Interval level. If "default", then it is set to 0.95 (95\% CI).
 #' @param method A character string indicating which correlation coefficient is to be used for the test. One of "pearson" (default), "kendall", or "spearman", "biserial", "polychoric", "tetrachoric", "biweight", "distance", "percentage" (for percentage bend correlation) or "shepherd" (for Shepherd's Pi correlation). Setting "auto" will attempt at selecting the most relevant method (polychoric when ordinal factors involved, tetrachoric when dichotomous factors involved, point-biserial if one dichotomous and one continuous and pearson otherwise).
-#' @param bayesian,partial_bayesian If TRUE, will run the correlations under a Bayesian framework Note that for partial correlations, you will also need to set \code{partial_bayesian} to \code{TRUE} to obtain "full" Bayesian partial correlations. Otherwise, you will obtain pseudo-Bayesian partial correlations (i.e., Bayesian correlation based on frequentist partialization).
+#' @param bayesian,partial_bayesian If TRUE, will run the correlations under a Bayesian framework. Note that for partial correlations, you will also need to set \code{partial_bayesian} to \code{TRUE} to obtain "full" Bayesian partial correlations. Otherwise, you will obtain pseudo-Bayesian partial correlations (i.e., Bayesian correlation based on frequentist partialization).
 #' @param include_factors If \code{TRUE}, the factors are kept and eventually converted to numeric or used as random effects (depending of \code{multilevel}). If \code{FALSE}, factors are removed upfront.
-#' @param partial Can be TRUE or "semi" for partial and semi-partial correlations, respectively. This only works for Frequentist correlations.
+#' @param partial Can be TRUE or "semi" for partial and semi-partial correlations, respectively.
 #' @inheritParams effectsize::adjust
 #' @param bayesian_prior For the prior argument, several named values are recognized: "medium.narrow", "medium", "wide", and "ultrawide". These correspond to scale values of 1/sqrt(27), 1/3, 1/sqrt(3) and 1, respectively. See the \code{BayesFactor::correlationBF} function.
 #' @param bayesian_ci_method,bayesian_test See arguments in \code{\link[=parameters]{model_parameters}} for \code{BayesFactor} tests.
@@ -21,6 +21,8 @@
 #'
 #'
 #' @examples
+#' library(correlation)
+#'
 #' cor_test(iris, "Sepal.Length", "Sepal.Width")
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", method = "spearman")
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", method = "kendall")
@@ -30,14 +32,14 @@
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", method = "shepherd")
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", bayesian = TRUE)
 #'
-#' data <- iris
 #' # Tetrachoric
+#' data <- iris
 #' data$Sepal.Width_binary <- ifelse(data$Sepal.Width > 3, 1, 0)
 #' data$Petal.Width_binary <- ifelse(data$Petal.Width > 1.2, 1, 0)
 #' cor_test(data, "Sepal.Width_binary", "Petal.Width_binary", method = "tetrachoric")
 #'
-#' # When one variable is continuous and the other binary, will run 'biserial' correlation
-#' cor_test(data, "Sepal.Width", "Petal.Width_binary", method = "tetrachoric")
+#' # Biserial
+#' cor_test(data, "Sepal.Width", "Petal.Width_binary", method = "biserial")
 #'
 #' # Polychoric
 #' data$Petal.Width_ordinal <- as.factor(round(data$Petal.Width))
@@ -50,21 +52,26 @@
 #' # Robust (these two are equivalent)
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", method = "pearson", robust = TRUE)
 #' cor_test(iris, "Sepal.Length", "Sepal.Width", method = "spearman", robust = FALSE)
+#'
+#' # Partial
+#' cor_test(iris, "Sepal.Length", "Sepal.Width", partial = TRUE)
+#' cor_test(iris, "Sepal.Length", "Sepal.Width", multilevel = TRUE)
+#' \donttest{
+#' cor_test(iris, "Sepal.Length", "Sepal.Width", partial_bayesian = TRUE)
+#' }
+#'
 #' @importFrom effectsize adjust ranktransform
 #' @importFrom stats complete.cases
 #' @export
-cor_test <- function(data, x, y, method = "pearson", ci = "default", bayesian = FALSE, bayesian_prior = "medium", bayesian_ci_method = "hdi", bayesian_test = c("pd", "rope", "bf"), include_factors = FALSE, partial = FALSE, partial_bayesian = FALSE, multilevel = FALSE, robust = FALSE, ...) {
+cor_test <- function(data, x, y, method = "pearson", ci = 0.95, bayesian = FALSE, bayesian_prior = "medium", bayesian_ci_method = "hdi", bayesian_test = c("pd", "rope", "bf"), include_factors = FALSE, partial = FALSE, partial_bayesian = FALSE, multilevel = FALSE, robust = FALSE, ...) {
 
   # Sanity checks
-  if (partial == FALSE & (partial_bayesian | multilevel)) {
-    if (partial_bayesian) {
-      warning("`partial` must be set to TRUE in order for `multilevel` to be used. Setting it to TRUE.")
-      partial <- TRUE
-    }
-    if (partial_bayesian) {
-      warning("`partial` must be set to TRUE in order for `partial_bayesian` to be used. Setting it to TRUE.")
-      partial <- TRUE
-    }
+  if (ci == "default") ci <- 0.95
+  if (partial == FALSE & (partial_bayesian | multilevel)) partial <- TRUE
+
+  # Make sure factor is no factor
+  if (!method %in% c("tetra", "tetrachoric", "poly", "polychoric")) {
+    data[c(x, y)] <- parameters::data_to_numeric(data[c(x, y)], dummy_factors = FALSE)
   }
 
   # Partial
@@ -78,23 +85,27 @@ cor_test <- function(data, x, y, method = "pearson", ci = "default", bayesian =
     data[c(x, y)] <- effectsize::ranktransform(data[c(x, y)], sign = TRUE, method = "average")
   }
 
+
+  # Find method
+  method <- tolower(method)
+  if (method == "auto" & bayesian == FALSE) method <- .find_correlationtype(data, x, y)
+  if (method == "auto" & bayesian == TRUE) method <- "pearson"
+
   # Frequentist
   if (bayesian == FALSE) {
-    if (ci == "default") ci <- 0.95
-
-    if (method == "auto") method <- .cor_test_findtype(data, x, y)
-
-    if (tolower(method) %in% c("tetra", "tetrachoric", "biserial")) {
+    if (method %in% c("tetra", "tetrachoric")) {
       out <- .cor_test_tetrachoric(data, x, y, ci = ci, ...)
-    } else if (tolower(method) %in% c("poly", "polychoric")) {
+    } else if (method %in% c("poly", "polychoric")) {
       out <- .cor_test_polychoric(data, x, y, ci = ci, ...)
-    } else if (tolower(method) %in% c("biweight")) {
+    } else if (method %in% c("biserial", "pointbiserial", "point-biserial")) {
+      out <- .cor_test_biserial(data, x, y, ci = ci, method = method, ...)
+    } else if (method %in% c("biweight")) {
       out <- .cor_test_biweight(data, x, y, ci = ci, ...)
-    } else if (tolower(method) %in% c("distance")) {
-      out <- .cor_test_distance(data, x, y, ci = ci, corrected = TRUE, ...)
-    } else if (tolower(method) %in% c("percentage", "percentage_bend", "percentagebend", "pb")) {
+    } else if (method %in% c("distance")) {
+      out <- .cor_test_distance(data, x, y, ci = ci, ...)
+    } else if (method %in% c("percentage", "percentage_bend", "percentagebend", "pb")) {
       out <- .cor_test_percentage(data, x, y, ci = ci, ...)
-    } else if (tolower(method) %in% c("shepherd", "sheperd", "shepherdspi", "pi")) {
+    } else if (method %in% c("shepherd", "sheperd", "shepherdspi", "pi")) {
       out <- .cor_test_shepherd(data, x, y, ci = ci, bayesian = FALSE, ...)
     } else {
       out <- .cor_test_freq(data, x, y, ci = ci, method = method, ...)
@@ -102,19 +113,19 @@ cor_test <- function(data, x, y, method = "pearson", ci = "default", bayesian =
 
     # Bayesian
   } else {
-    if (ci == "default") ci <- 0.89
-
-    if (tolower(method) %in% c("tetra", "tetrachoric")) {
+    if (method %in% c("tetra", "tetrachoric")) {
       stop("Tetrachoric Bayesian correlations are not supported yet.")
-    } else if (tolower(method) %in% c("poly", "polychoric")) {
+    } else if (method %in% c("poly", "polychoric")) {
       stop("Polychoric Bayesian correlations are not supported yet.")
-    } else if (tolower(method) %in% c("biweight")) {
+    } else if (method %in% c("biserial", "pointbiserial", "point-biserial")) {
+      stop("Biserial Bayesian correlations are not supported yet.")
+    } else if (method %in% c("biweight")) {
       stop("Biweight Bayesian correlations are not supported yet.")
-    } else if (tolower(method) %in% c("distance")) {
+    } else if (method %in% c("distance")) {
       stop("Bayesian distance correlations are not supported yet.")
-    } else if (tolower(method) %in% c("percentage", "percentage_bend", "percentagebend", "pb")) {
+    } else if (method %in% c("percentage", "percentage_bend", "percentagebend", "pb")) {
       stop("Bayesian Percentage Bend correlations are not supported yet.")
-    } else if (tolower(method) %in% c("shepherd", "sheperd", "shepherdspi", "pi")) {
+    } else if (method %in% c("shepherd", "sheperd", "shepherdspi", "pi")) {
       out <- .cor_test_shepherd(data, x, y, ci = ci, bayesian = TRUE, ...)
     } else {
       out <- .cor_test_bayes(data, x, y, ci = ci, bayesian_prior = bayesian_prior, bayesian_ci_method = bayesian_ci_method, bayesian_test = bayesian_test, ...)
@@ -124,6 +135,13 @@ cor_test <- function(data, x, y, method = "pearson", ci = "default", bayesian =
   # Number of observations
   out$n_Obs <- sum(stats::complete.cases(data[[x]], data[[y]]))
 
+  # Reorder columns
+  if ("CI_low" %in% names(out)) {
+    order <- c("Parameter1", "Parameter2", "r", "rho", "CI_low", "CI_high")
+    out <- out[c(order[order %in% names(out)], setdiff(colnames(out), order[order %in% names(out)]))]
+  }
+
+  # Output
   attr(out, "ci") <- ci
   class(out) <- unique(c("easycorrelation", "parameters_model", class(out)))
   out
@@ -146,17 +164,3 @@ cor_test <- function(data, x, y, method = "pearson", ci = "default", bayesian =
 .complete_variable_y <- function(data, x, y) {
   data[[y]][stats::complete.cases(data[[x]], data[[y]])]
 }
-
-
-
-#' @keywords internal
-.cor_test_findtype <- function(data, x, y) {
-  if (length(unique(data[[x]])) == 2 | length(unique(data[[y]])) == 2) {
-    current_method <- "tetrachoric"
-  } else if (is.factor(data[x]) | is.factor(data[y])) {
-    current_method <- "polychoric"
-  } else {
-    current_method <- "pearson"
-  }
-  current_method
-}
