@@ -137,7 +137,7 @@ pcor_to_cor.easycorrelation <- function(pcor, tol = .Machine$double.eps^(2 / 3))
   # Fix for spearman
   if (any(cor$Method == "Spearman")) {
     newdata$df <- NULL
-    names(newdata)[names(newdata) == 't'] <- 'S'
+    names(newdata)[names(newdata) == "t"] <- "S"
     newdata$Method <- "Spearman"
   }
 
