@@ -9,7 +9,7 @@ test_that("pcor_to_cor", {
 
     # easycormatrix
     out <- correlation(iris, partial = TRUE, p_adjust = "none")
-    pcormat <- as.table(out)
+    pcormat <- summary(out, redundant = TRUE)
 
     ppcor <- ppcor::pcor(iris[1:4])
     testthat::expect_equal(max(as.matrix(pcormat[2:5]) - as.matrix(ppcor$estimate)), 0, tol = 0.01)
@@ -24,7 +24,7 @@ test_that("pcor_to_cor", {
     testthat::expect_equal(mean(p - hmisc$P, na.rm = TRUE), 0, tol = 0.001)
 
     # easycorrelation
-    cormat <- as.table(pcor_to_cor(correlation(iris, partial = TRUE)))
+    cormat <- summary(pcor_to_cor(correlation(iris, partial = TRUE)), redundant = TRUE)
 
     testthat::expect_equal(max(as.matrix(cormat[2:5]) - as.matrix(cor(iris[1:4]))), 0, tol = 0.01)
 
@@ -44,7 +44,7 @@ test_that("cor_to_pcor", {
 
     # easycormatrix
     out <- correlation(iris)
-    cormat <- as.table(out)
+    cormat <- summary(out, redundant = TRUE)
     pcormat <- cor_to_pcor(cormat)
 
     ppcor <- ppcor::pcor(iris[1:4])
@@ -52,7 +52,7 @@ test_that("cor_to_pcor", {
     testthat::expect_equal(max(as.matrix(attributes(pcormat)$p[2:5]) - as.matrix(ppcor$p.value)), 0, tol = 0.01)
 
     # easycorrelation
-    pcormat <- as.table(cor_to_pcor(correlation(iris)))
+    pcormat <- summary(cor_to_pcor(correlation(iris)), redundant = TRUE)
 
     ppcor <- ppcor::pcor(iris[1:4])
     testthat::expect_equal(max(as.matrix(pcormat[2:5]) - as.matrix(ppcor$estimate)), 0, tol = 0.01)
@@ -76,7 +76,7 @@ test_that("spcor_to_cor", {
 
     # easycormatrix
     out <- correlation(iris)
-    cormat <- as.table(out)
+    cormat <- summary(out, redundant = TRUE)
     spcormat <- cor_to_spcor(cormat, cov = cov(iris[1:4]))
 
     spcor <- ppcor::spcor(iris[1:4])
